.. DataRobot Python SDK documentation master file, created by
   sphinx-quickstart on Mon Mar 16 10:50:19 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

DataRobot Python SDK
====================

.. toctree::
   :maxdepth: 2

   setup/installation.rst
   entities/quickstart.rst
   entities/project.rst
   entities/blueprint.rst
   entities/model.rst
   entities/model_job.rst
   entities/predict_job.rst
   api/index.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

